==> bitstream_1.1.orig.tar.bz2: bitstream-1.1/dvb/si/descs_list.h <==
/*****************************************************************************
 * descs_list.h: All supported ETSI EN 300 468 descriptors
 *****************************************************************************
 * Copyright (C) 2009-2010 VideoLAN
 *
 * Authors: Christophe Massiot <massiot@via.ecp.fr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef __BITSTREAM_DVB_DESCS_LIST_H__
#define __BITSTREAM_DVB_DESCS_LIST_H__

/*
 * 1. Keep the list ordered.
 * 2. When you are adding new descriptor here, make sure you also add
 *    the needed code in bitstream/mpeg/psi/descs_print.h
 */

#include <bitstream/dvb/si/desc_40.h>
#include <bitstream/dvb/si/desc_41.h>
#include <bitstream/dvb/si/desc_42.h>
#include <bitstream/dvb/si/desc_43.h>
#include <bitstream/dvb/si/desc_44.h>
#include <bitstream/dvb/si/desc_45.h>
#include <bitstream/dvb/si/desc_46.h>
#include <bitstream/dvb/si/desc_47.h>
#include <bitstream/dvb/si/desc_48.h>
#include <bitstream/dvb/si/desc_49.h>
#include <bitstream/dvb/si/desc_4a.h>
#include <bitstream/dvb/si/desc_4b.h>
#include <bitstream/dvb/si/desc_4c.h>
#include <bitstream/dvb/si/desc_4d.h>
#include <bitstream/dvb/si/desc_4e.h>
#include <bitstream/dvb/si/desc_4f.h>
#include <bitstream/dvb/si/desc_50.h>
#include <bitstream/dvb/si/desc_51.h>
#include <bitstream/dvb/si/desc_52.h>
#include <bitstream/dvb/si/desc_53.h>
#include <bitstream/dvb/si/desc_54.h>
#include <bitstream/dvb/si/desc_55.h>
#include <bitstream/dvb/si/desc_56.h>
#include <bitstream/dvb/si/desc_57.h>
#include <bitstream/dvb/si/desc_58.h>
#include <bitstream/dvb/si/desc_59.h>
#include <bitstream/dvb/si/desc_5a.h>
#include <bitstream/dvb/si/desc_5b.h>
#include <bitstream/dvb/si/desc_5c.h>
#include <bitstream/dvb/si/desc_5d.h>
#include <bitstream/dvb/si/desc_5e.h>
#include <bitstream/dvb/si/desc_5f.h>
#include <bitstream/dvb/si/desc_60.h>
#include <bitstream/dvb/si/desc_61.h>
#include <bitstream/dvb/si/desc_62.h>
#include <bitstream/dvb/si/desc_63.h>
#include <bitstream/dvb/si/desc_64.h>
#include <bitstream/dvb/si/desc_65.h>
#include <bitstream/dvb/si/desc_66.h>
#include <bitstream/dvb/si/desc_67.h>
#include <bitstream/dvb/si/desc_68.h>
#include <bitstream/dvb/si/desc_69.h>
#include <bitstream/dvb/si/desc_6a.h>
#include <bitstream/dvb/si/desc_6b.h>
#include <bitstream/dvb/si/desc_6c.h>
#include <bitstream/dvb/si/desc_6d.h>
#include <bitstream/dvb/si/desc_6e.h>
#include <bitstream/dvb/si/desc_7a.h>
#include <bitstream/dvb/si/desc_7b.h>
#include <bitstream/dvb/si/desc_7c.h>
#include <bitstream/dvb/si/desc_83p28.h>
#include <bitstream/dvb/si/desc_88p28.h>

#endif

==> bitstream_1.6.orig.tar.bz2: bitstream-1.6/dvb/si/descs_list.h <==
/*****************************************************************************
 * descs_list.h: All supported ETSI EN 300 468 descriptors
 *****************************************************************************
 * Copyright (C) 2009-2010 VideoLAN
 *
 * Authors: Christophe Massiot <massiot@via.ecp.fr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef __BITSTREAM_DVB_DESCS_LIST_H__
#define __BITSTREAM_DVB_DESCS_LIST_H__

/*
 * 1. Keep the list ordered.
 * 2. When you are adding new descriptor here, make sure you also add
 *    the needed code in bitstream/mpeg/psi/descs_print.h
 */

#include <bitstream/dvb/si/desc_40.h>
#include <bitstream/dvb/si/desc_41.h>
#include <bitstream/dvb/si/desc_42.h>
#include <bitstream/dvb/si/desc_43.h>
#include <bitstream/dvb/si/desc_44.h>
#include <bitstream/dvb/si/desc_45.h>
#include <bitstream/dvb/si/desc_46.h>
#include <bitstream/dvb/si/desc_47.h>
#include <bitstream/dvb/si/desc_48.h>
#include <bitstream/dvb/si/desc_49.h>
#include <bitstream/dvb/si/desc_4a.h>
#include <bitstream/dvb/si/desc_4b.h>
#include <bitstream/dvb/si/desc_4c.h>
#include <bitstream/dvb/si/desc_4d.h>
#include <bitstream/dvb/si/desc_4e.h>
#include <bitstream/dvb/si/desc_4f.h>
#include <bitstream/dvb/si/desc_50.h>
#include <bitstream/dvb/si/desc_51.h>
#include <bitstream/dvb/si/desc_52.h>
#include <bitstream/dvb/si/desc_53.h>
#include <bitstream/dvb/si/desc_54.h>
#include <bitstream/dvb/si/desc_55.h>
#include <bitstream/dvb/si/desc_56.h>
#include <bitstream/dvb/si/desc_57.h>
#include <bitstream/dvb/si/desc_58.h>
#include <bitstream/dvb/si/desc_59.h>
#include <bitstream/dvb/si/desc_5a.h>
#include <bitstream/dvb/si/desc_5b.h>
#include <bitstream/dvb/si/desc_5c.h>
#include <bitstream/dvb/si/desc_5d.h>
#include <bitstream/dvb/si/desc_5e.h>
#include <bitstream/dvb/si/desc_5f.h>
#include <bitstream/dvb/si/desc_60.h>
#include <bitstream/dvb/si/desc_61.h>
#include <bitstream/dvb/si/desc_62.h>
#include <bitstream/dvb/si/desc_63.h>
#include <bitstream/dvb/si/desc_64.h>
#include <bitstream/dvb/si/desc_65.h>
#include <bitstream/dvb/si/desc_66.h>
#include <bitstream/dvb/si/desc_67.h>
#include <bitstream/dvb/si/desc_68.h>
#include <bitstream/dvb/si/desc_69.h>
#include <bitstream/dvb/si/desc_6a.h>
#include <bitstream/dvb/si/desc_6b.h>
#include <bitstream/dvb/si/desc_6c.h>
#include <bitstream/dvb/si/desc_6d.h>
#include <bitstream/dvb/si/desc_6e.h>
#include <bitstream/dvb/si/desc_6f.h>
#include <bitstream/dvb/si/desc_7a.h>
#include <bitstream/dvb/si/desc_7b.h>
#include <bitstream/dvb/si/desc_7c.h>
#include <bitstream/dvb/si/desc_7f.h>
#include <bitstream/dvb/si/desc_7f00.h>
#include <bitstream/dvb/si/desc_7f06.h>
#include <bitstream/dvb/si/desc_7f15.h>
#include <bitstream/dvb/si/desc_7f19.h>
#include <bitstream/dvb/si/desc_83p28.h>
#include <bitstream/dvb/si/desc_88p28.h>

#endif
